@@ -3,7 +3,7 @@ from hypernetx.exception import (
     HyperNetXError,
     HyperNetXNotImplementedError,
 )
-from hypernetx.read_write import to_pickle, load_from_pickle
+from hypernetx.hif import to_hif, from_hif
 from hypernetx.classes import *
 from hypernetx.reports import *
 from hypernetx.drawing import *
@@ -11,4 +11,4 @@ from hypernetx.algorithms import *
 from hypernetx.utils import *
 from hypernetx.utils.toys import *
 
-__version__ = "2.0.5"
+__version__ = "2.3.10"
