@@ -68,10 +68,10 @@ def contagion_animation(
     try:
         from celluloid import Camera
     except ModuleNotFoundError as e:
-        print(
-            f" {e}. If you need to use {__name__}, please install additional packages by running the following command: pip install .['all']"
-        )
-        raise
+        raise Exception(
+            f"If you need to use {__name__}, please install additional packages by running the "
+            f"following command: pip install celluloid"
+        ) from e
 
     nodeState = defaultdict(lambda: "S")
 
@@ -308,6 +308,7 @@ def majority_vote(node, status, edge):
 
 # Auxiliary functions
 
+
 # The ListDict class is copied from Joel Miller's Github repository Mathematics-of-Epidemics-on-Networks
 class _ListDict_(object):
     r"""
@@ -537,7 +538,7 @@ def discrete_SIR(
         if rho is None:
             initial_number = 1
         else:
-            initial_number = int(round(H.number_of_nodes() * rho))
+            initial_number = int(round(len(H.nodes) * rho))
         initial_infecteds = random.sample(list(H.nodes), initial_number)
     else:
         # check to make sure that the initially infected nodes are in the hypergraph
@@ -567,13 +568,13 @@ def discrete_SIR(
 
     I = [len(initial_infecteds)]
     R = [len(initial_recovereds)]
-    S = [H.number_of_nodes() - I[-1] - R[-1]]
+    S = [len(H.nodes) - I[-1] - R[-1]]
 
     t = tmin
     times = [t]
     newStatus = status.copy()
 
-    edge_neighbors = lambda node: H.edges.memberships[node]
+    edge_neighbors = lambda node: H.nodes.memberships[node]
 
     while t < tmax and I[-1] != 0:
         # Initialize the next step with the same numbers of S, I, and R as the last step before computing the changes
@@ -699,7 +700,7 @@ def discrete_SIS(
         if rho is None:
             initial_number = 1
         else:
-            initial_number = int(round(H.number_of_nodes() * rho))
+            initial_number = int(round(len(H.nodes) * rho))
         initial_infecteds = random.sample(list(H.nodes), initial_number)
     else:
         # check to make sure that the initially infected nodes are in the hypergraph
@@ -717,13 +718,13 @@ def discrete_SIS(
             transition_events[tmin].append(("I", node, None))
 
     I = [len(initial_infecteds)]
-    S = [H.number_of_nodes() - I[-1]]
+    S = [len(H.nodes) - I[-1]]
 
     t = tmin
     times = [t]
     newStatus = status.copy()
 
-    edge_neighbors = lambda node: H.edges.memberships[node]
+    edge_neighbors = lambda node: H.nodes.memberships[node]
 
     while t < tmax and I[-1] != 0:
         # Initialize the next step with the same numbers of S, I, and R as the last step before computing the changes
@@ -843,7 +844,7 @@ def Gillespie_SIR(
         if rho is None:
             initial_number = 1
         else:
-            initial_number = int(round(H.number_of_nodes() * rho))
+            initial_number = int(round(len(H.nodes) * rho))
         initial_infecteds = random.sample(list(H.nodes), initial_number)
     else:
         # check to make sure that the initially infected nodes are in the hypergraph
@@ -867,9 +868,9 @@ def Gillespie_SIR(
 
     I = [len(initial_infecteds)]
     R = [len(initial_recovereds)]
-    S = [H.number_of_nodes() - I[-1] - R[-1]]
+    S = [len(H.nodes) - I[-1] - R[-1]]
 
-    edge_neighbors = lambda node: H.edges.memberships[node]
+    edge_neighbors = lambda node: H.nodes.memberships[node]
 
     t = tmin
     times = [t]
@@ -1042,7 +1043,7 @@ def Gillespie_SIS(
         if rho is None:
             initial_number = 1
         else:
-            initial_number = int(round(H.number_of_nodes() * rho))
+            initial_number = int(round(len(H.nodes) * rho))
         initial_infecteds = random.sample(list(H.nodes), initial_number)
     else:
         # check to make sure that the initially infected nodes are in the hypergraph
@@ -1056,9 +1057,9 @@ def Gillespie_SIS(
         status[node] = "I"
 
     I = [len(initial_infecteds)]
-    S = [H.number_of_nodes() - I[-1]]
+    S = [len(H.nodes) - I[-1]]
 
-    edge_neighbors = lambda node: H.edges.memberships[node]
+    edge_neighbors = lambda node: H.nodes.memberships[node]
 
     t = tmin
     times = [t]
