@@ -8,6 +8,7 @@ This module contains methods which compute various distributions for hypergraphs
 
 Also computes general hypergraph information: number of nodes, edges, cells, aspect ratio, incidence matrix density
 """
+
 from collections import Counter
 import numpy as np
 from hypernetx.utils.decorators import not_implemented_for
@@ -42,7 +43,7 @@ def edge_size_dist(H, aggregated=False):
 
     Parameters
     ----------
-    H : Hypergraph
+    H: hnx.Hypergraph
     aggregated :
         If aggregated is True, returns a dictionary of
         edge sizes and counts. If aggregated is False, returns a
@@ -66,7 +67,7 @@ def degree_dist(H, aggregated=False):
 
     Parameters
     ----------
-    H : Hypergraph
+    H: hnx.Hypergraph
     aggregated :
         If aggregated is True, returns a dictionary of
         degrees and counts. If aggregated is False, returns a
@@ -90,7 +91,7 @@ def comp_dist(H, aggregated=False):
 
     Parameters
     ----------
-    H : Hypergraph
+    H: hnx.Hypergraph
     aggregated :
         If aggregated is True, returns a dictionary of
         component sizes (number of nodes) and counts. If aggregated
@@ -120,7 +121,7 @@ def s_comp_dist(H, s=1, aggregated=False, edges=True, return_singletons=True):
 
     Parameters
     ----------
-    H : Hypergraph
+    H: hnx.Hypergraph
     s : positive integer, default is 1
     aggregated :
         If aggregated is True, returns a dictionary of
@@ -162,7 +163,7 @@ def toplex_dist(H, aggregated=False):
 
     Parameters
     ----------
-    H : Hypergraph
+    H: hnx.Hypergraph
     aggregated :
         If aggregated is True, returns a dictionary of
         toplex sizes and counts in H. If aggregated
@@ -184,7 +185,7 @@ def s_node_diameter_dist(H):
     """
     Parameters
     ----------
-    H : Hypergraph
+    H: hnx.Hypergraph
 
     Returns
     -------
@@ -204,7 +205,7 @@ def s_edge_diameter_dist(H):
     """
     Parameters
     ----------
-    H : Hypergraph
+    H: hnx.Hypergraph
 
     Returns
     -------
@@ -226,7 +227,7 @@ def info(H, node=None, edge=None):
 
     Parameters
     ----------
-    H : Hypergraph
+    H: hnx.Hypergraph
     obj : optional
         either a node or edge uid from the hypergraph
     dictionary : optional
@@ -270,7 +271,7 @@ def info_dict(H, node=None, edge=None):
 
     Parameters
     ----------
-    H : Hypergraph
+    H: hnx.Hypergraph
     obj : optional
         either a node or edge uid from the hypergraph
 
@@ -334,7 +335,7 @@ def dist_stats(H):
 
     Parameters
     ----------
-    H : Hypergraph
+    H: hnx.Hypergraph
 
     Returns
     -------
